pub struct ConnectParams {
pub endpoint: String,
}Fields
endpoint: StringTrait Implementations
Sourceimpl Debug for ConnectParams
impl Debug for ConnectParams
Sourceimpl<'de> Deserialize<'de> for ConnectParams
impl<'de> Deserialize<'de> for ConnectParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConnectParams
impl JsonSchema for ConnectParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConnectParams
impl RefUnwindSafe for ConnectParams
impl Send for ConnectParams
impl Sync for ConnectParams
impl Unpin for ConnectParams
impl UnsafeUnpin for ConnectParams
impl UnwindSafe for ConnectParams