pub struct CreateCheckpointParams {
pub description: Option<String>,
}Fields
description: Option<String>Trait Implementations
Sourceimpl Debug for CreateCheckpointParams
impl Debug for CreateCheckpointParams
Sourceimpl<'de> Deserialize<'de> for CreateCheckpointParams
impl<'de> Deserialize<'de> for CreateCheckpointParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateCheckpointParams
impl JsonSchema for CreateCheckpointParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateCheckpointParams
impl RefUnwindSafe for CreateCheckpointParams
impl Send for CreateCheckpointParams
impl Sync for CreateCheckpointParams
impl Unpin for CreateCheckpointParams
impl UnsafeUnpin for CreateCheckpointParams
impl UnwindSafe for CreateCheckpointParams