pub struct EndDebugSessionParams {
pub outcome: Option<String>,
}Fields
outcome: Option<String>Trait Implementations
Sourceimpl Debug for EndDebugSessionParams
impl Debug for EndDebugSessionParams
Sourceimpl<'de> Deserialize<'de> for EndDebugSessionParams
impl<'de> Deserialize<'de> for EndDebugSessionParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EndDebugSessionParams
impl JsonSchema for EndDebugSessionParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EndDebugSessionParams
impl RefUnwindSafe for EndDebugSessionParams
impl Send for EndDebugSessionParams
impl Sync for EndDebugSessionParams
impl Unpin for EndDebugSessionParams
impl UnsafeUnpin for EndDebugSessionParams
impl UnwindSafe for EndDebugSessionParams