pub struct ForgetMemoryParams {
pub id: String,
pub confirm: Option<bool>,
}Fields
id: Stringconfirm: Option<bool>Trait Implementations
Sourceimpl Debug for ForgetMemoryParams
impl Debug for ForgetMemoryParams
Sourceimpl<'de> Deserialize<'de> for ForgetMemoryParams
impl<'de> Deserialize<'de> for ForgetMemoryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ForgetMemoryParams
impl JsonSchema for ForgetMemoryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForgetMemoryParams
impl RefUnwindSafe for ForgetMemoryParams
impl Send for ForgetMemoryParams
impl Sync for ForgetMemoryParams
impl Unpin for ForgetMemoryParams
impl UnsafeUnpin for ForgetMemoryParams
impl UnwindSafe for ForgetMemoryParams