pub struct HelpParams {
pub topic: Option<String>,
}Fields
topic: Option<String>Trait Implementations
Sourceimpl Debug for HelpParams
impl Debug for HelpParams
Sourceimpl<'de> Deserialize<'de> for HelpParams
impl<'de> Deserialize<'de> for HelpParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HelpParams
impl JsonSchema for HelpParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HelpParams
impl RefUnwindSafe for HelpParams
impl Send for HelpParams
impl Sync for HelpParams
impl Unpin for HelpParams
impl UnsafeUnpin for HelpParams
impl UnwindSafe for HelpParams