pub struct QueryMemoryParams {
pub text: Option<String>,
pub kinds: Option<Vec<String>>,
pub tags: Option<Vec<String>>,
pub project_slug: Option<String>,
pub limit: Option<u64>,
}Fields
text: Option<String>kinds: Option<Vec<String>>project_slug: Option<String>limit: Option<u64>Trait Implementations
Sourceimpl Debug for QueryMemoryParams
impl Debug for QueryMemoryParams
Sourceimpl<'de> Deserialize<'de> for QueryMemoryParams
impl<'de> Deserialize<'de> for QueryMemoryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryMemoryParams
impl JsonSchema for QueryMemoryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QueryMemoryParams
impl RefUnwindSafe for QueryMemoryParams
impl Send for QueryMemoryParams
impl Sync for QueryMemoryParams
impl Unpin for QueryMemoryParams
impl UnsafeUnpin for QueryMemoryParams
impl UnwindSafe for QueryMemoryParams