pub struct ResolveDebugSessionParams {
pub summary: String,
pub root_cause: Option<String>,
pub fix_diff: Option<String>,
pub commands_used: Option<Vec<String>>,
pub related_errors: Option<Vec<String>>,
pub tags: Option<Vec<String>>,
}Fields
summary: Stringroot_cause: Option<String>fix_diff: Option<String>commands_used: Option<Vec<String>>Trait Implementations
Sourceimpl Debug for ResolveDebugSessionParams
impl Debug for ResolveDebugSessionParams
Sourceimpl<'de> Deserialize<'de> for ResolveDebugSessionParams
impl<'de> Deserialize<'de> for ResolveDebugSessionParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResolveDebugSessionParams
impl JsonSchema for ResolveDebugSessionParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResolveDebugSessionParams
impl RefUnwindSafe for ResolveDebugSessionParams
impl Send for ResolveDebugSessionParams
impl Sync for ResolveDebugSessionParams
impl Unpin for ResolveDebugSessionParams
impl UnsafeUnpin for ResolveDebugSessionParams
impl UnwindSafe for ResolveDebugSessionParams