pub struct SaveMemoryParams {
pub content: String,
pub kind: Option<String>,
pub tags: Option<Vec<String>>,
pub source_observations: Option<Vec<u64>>,
pub project_slug: Option<String>,
pub session_id: Option<String>,
pub confidence: Option<f64>,
}Fields
content: Stringkind: Option<String>source_observations: Option<Vec<u64>>project_slug: Option<String>session_id: Option<String>confidence: Option<f64>Trait Implementations
Sourceimpl Debug for SaveMemoryParams
impl Debug for SaveMemoryParams
Sourceimpl<'de> Deserialize<'de> for SaveMemoryParams
impl<'de> Deserialize<'de> for SaveMemoryParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SaveMemoryParams
impl JsonSchema for SaveMemoryParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SaveMemoryParams
impl RefUnwindSafe for SaveMemoryParams
impl Send for SaveMemoryParams
impl Sync for SaveMemoryParams
impl Unpin for SaveMemoryParams
impl UnsafeUnpin for SaveMemoryParams
impl UnwindSafe for SaveMemoryParams