pub struct SetupApplyParams {
pub cwd: Option<String>,
pub yes: bool,
pub providers: Option<String>,
}Fields
cwd: Option<String>yes: boolproviders: Option<String>Trait Implementations
Sourceimpl Debug for SetupApplyParams
impl Debug for SetupApplyParams
Sourceimpl<'de> Deserialize<'de> for SetupApplyParams
impl<'de> Deserialize<'de> for SetupApplyParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetupApplyParams
impl JsonSchema for SetupApplyParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetupApplyParams
impl RefUnwindSafe for SetupApplyParams
impl Send for SetupApplyParams
impl Sync for SetupApplyParams
impl Unpin for SetupApplyParams
impl UnsafeUnpin for SetupApplyParams
impl UnwindSafe for SetupApplyParams