pub struct SetupPlanParams {
pub cwd: Option<String>,
}Fields
cwd: Option<String>Trait Implementations
Sourceimpl Debug for SetupPlanParams
impl Debug for SetupPlanParams
Sourceimpl<'de> Deserialize<'de> for SetupPlanParams
impl<'de> Deserialize<'de> for SetupPlanParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetupPlanParams
impl JsonSchema for SetupPlanParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetupPlanParams
impl RefUnwindSafe for SetupPlanParams
impl Send for SetupPlanParams
impl Sync for SetupPlanParams
impl Unpin for SetupPlanParams
impl UnsafeUnpin for SetupPlanParams
impl UnwindSafe for SetupPlanParams