pub struct SetupToolAction {
pub action: String,
pub cwd: Option<String>,
pub yes: Option<bool>,
pub providers: Option<String>,
}Fields
action: Stringcwd: Option<String>yes: Option<bool>providers: Option<String>Trait Implementations
Sourceimpl Clone for SetupToolAction
impl Clone for SetupToolAction
Sourcefn clone(&self) -> SetupToolAction
fn clone(&self) -> SetupToolAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetupToolAction
impl Debug for SetupToolAction
Sourceimpl<'de> Deserialize<'de> for SetupToolAction
impl<'de> Deserialize<'de> for SetupToolAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SetupToolAction
impl JsonSchema for SetupToolAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SetupToolAction
impl RefUnwindSafe for SetupToolAction
impl Send for SetupToolAction
impl Sync for SetupToolAction
impl Unpin for SetupToolAction
impl UnsafeUnpin for SetupToolAction
impl UnwindSafe for SetupToolAction