pub struct SubscribeParams {
pub kinds: Option<Vec<String>>,
pub severity_min: Option<String>,
pub origins: Option<Vec<String>>,
pub text_match: Option<String>,
pub correlation_id: Option<String>,
pub tags: Option<Vec<String>>,
pub include_system: Option<bool>,
}Fields
kinds: Option<Vec<String>>severity_min: Option<String>origins: Option<Vec<String>>text_match: Option<String>correlation_id: Option<String>include_system: Option<bool>Trait Implementations
Sourceimpl Debug for SubscribeParams
impl Debug for SubscribeParams
Sourceimpl<'de> Deserialize<'de> for SubscribeParams
impl<'de> Deserialize<'de> for SubscribeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubscribeParams
impl JsonSchema for SubscribeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubscribeParams
impl RefUnwindSafe for SubscribeParams
impl Send for SubscribeParams
impl Sync for SubscribeParams
impl Unpin for SubscribeParams
impl UnsafeUnpin for SubscribeParams
impl UnwindSafe for SubscribeParams